# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['telecoin',
 'telecoin.venv.Lib.site-packages',
 'telecoin.venv.Lib.site-packages._distutils_hack',
 'telecoin.venv.Lib.site-packages.aiohttp',
 'telecoin.venv.Lib.site-packages.async_timeout',
 'telecoin.venv.Lib.site-packages.attr',
 'telecoin.venv.Lib.site-packages.chardet',
 'telecoin.venv.Lib.site-packages.chardet.cli',
 'telecoin.venv.Lib.site-packages.chardet.metadata',
 'telecoin.venv.Lib.site-packages.idna',
 'telecoin.venv.Lib.site-packages.multidict',
 'telecoin.venv.Lib.site-packages.pip',
 'telecoin.venv.Lib.site-packages.pip._internal',
 'telecoin.venv.Lib.site-packages.pip._internal.cli',
 'telecoin.venv.Lib.site-packages.pip._internal.commands',
 'telecoin.venv.Lib.site-packages.pip._internal.distributions',
 'telecoin.venv.Lib.site-packages.pip._internal.index',
 'telecoin.venv.Lib.site-packages.pip._internal.locations',
 'telecoin.venv.Lib.site-packages.pip._internal.metadata',
 'telecoin.venv.Lib.site-packages.pip._internal.models',
 'telecoin.venv.Lib.site-packages.pip._internal.network',
 'telecoin.venv.Lib.site-packages.pip._internal.operations',
 'telecoin.venv.Lib.site-packages.pip._internal.operations.build',
 'telecoin.venv.Lib.site-packages.pip._internal.operations.install',
 'telecoin.venv.Lib.site-packages.pip._internal.req',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution.legacy',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution.resolvelib',
 'telecoin.venv.Lib.site-packages.pip._internal.utils',
 'telecoin.venv.Lib.site-packages.pip._internal.vcs',
 'telecoin.venv.Lib.site-packages.pip._vendor',
 'telecoin.venv.Lib.site-packages.pip._vendor.cachecontrol',
 'telecoin.venv.Lib.site-packages.pip._vendor.cachecontrol.caches',
 'telecoin.venv.Lib.site-packages.pip._vendor.certifi',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet.cli',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet.metadata',
 'telecoin.venv.Lib.site-packages.pip._vendor.colorama',
 'telecoin.venv.Lib.site-packages.pip._vendor.distlib',
 'telecoin.venv.Lib.site-packages.pip._vendor.distlib._backport',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib._trie',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.filters',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treeadapters',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treebuilders',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treewalkers',
 'telecoin.venv.Lib.site-packages.pip._vendor.idna',
 'telecoin.venv.Lib.site-packages.pip._vendor.msgpack',
 'telecoin.venv.Lib.site-packages.pip._vendor.packaging',
 'telecoin.venv.Lib.site-packages.pip._vendor.pep517',
 'telecoin.venv.Lib.site-packages.pip._vendor.pep517.in_process',
 'telecoin.venv.Lib.site-packages.pip._vendor.pkg_resources',
 'telecoin.venv.Lib.site-packages.pip._vendor.progress',
 'telecoin.venv.Lib.site-packages.pip._vendor.requests',
 'telecoin.venv.Lib.site-packages.pip._vendor.resolvelib',
 'telecoin.venv.Lib.site-packages.pip._vendor.resolvelib.compat',
 'telecoin.venv.Lib.site-packages.pip._vendor.tenacity',
 'telecoin.venv.Lib.site-packages.pip._vendor.toml',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.contrib',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.contrib._securetransport',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages.backports',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages.ssl_match_hostname',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.util',
 'telecoin.venv.Lib.site-packages.pip._vendor.webencodings',
 'telecoin.venv.Lib.site-packages.pkg_resources',
 'telecoin.venv.Lib.site-packages.pkg_resources._vendor',
 'telecoin.venv.Lib.site-packages.pkg_resources._vendor.packaging',
 'telecoin.venv.Lib.site-packages.pkg_resources.extern',
 'telecoin.venv.Lib.site-packages.pkg_resources.tests.data.my-test-package-source',
 'telecoin.venv.Lib.site-packages.pyaes',
 'telecoin.venv.Lib.site-packages.pyrogram',
 'telecoin.venv.Lib.site-packages.pyrogram.connection',
 'telecoin.venv.Lib.site-packages.pyrogram.connection.transport',
 'telecoin.venv.Lib.site-packages.pyrogram.connection.transport.tcp',
 'telecoin.venv.Lib.site-packages.pyrogram.crypto',
 'telecoin.venv.Lib.site-packages.pyrogram.errors',
 'telecoin.venv.Lib.site-packages.pyrogram.errors.exceptions',
 'telecoin.venv.Lib.site-packages.pyrogram.handlers',
 'telecoin.venv.Lib.site-packages.pyrogram.methods',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.advanced',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.bots',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.chats',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.decorators',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.invite_links',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.password',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.users',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.utilities',
 'telecoin.venv.Lib.site-packages.pyrogram.parser',
 'telecoin.venv.Lib.site-packages.pyrogram.raw',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.core',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.core.primitives',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.bots',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.contest',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.folders',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.langpack',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.stickers',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.users',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.session',
 'telecoin.venv.Lib.site-packages.pyrogram.session.internals',
 'telecoin.venv.Lib.site-packages.pyrogram.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.types',
 'telecoin.venv.Lib.site-packages.pyrogram.types.authorization',
 'telecoin.venv.Lib.site-packages.pyrogram.types.bots_and_keyboards',
 'telecoin.venv.Lib.site-packages.pyrogram.types.inline_mode',
 'telecoin.venv.Lib.site-packages.pyrogram.types.input_media',
 'telecoin.venv.Lib.site-packages.pyrogram.types.input_message_content',
 'telecoin.venv.Lib.site-packages.pyrogram.types.messages_and_media',
 'telecoin.venv.Lib.site-packages.pyrogram.types.user_and_chats',
 'telecoin.venv.Lib.site-packages.setuptools',
 'telecoin.venv.Lib.site-packages.setuptools._distutils',
 'telecoin.venv.Lib.site-packages.setuptools._distutils.command',
 'telecoin.venv.Lib.site-packages.setuptools._vendor',
 'telecoin.venv.Lib.site-packages.setuptools._vendor.more_itertools',
 'telecoin.venv.Lib.site-packages.setuptools._vendor.packaging',
 'telecoin.venv.Lib.site-packages.setuptools.command',
 'telecoin.venv.Lib.site-packages.setuptools.extern',
 'telecoin.venv.Lib.site-packages.wheel',
 'telecoin.venv.Lib.site-packages.wheel.cli',
 'telecoin.venv.Lib.site-packages.wheel.vendored',
 'telecoin.venv.Lib.site-packages.wheel.vendored.packaging',
 'telecoin.venv.Lib.site-packages.yarl',
 'telecoin.venv.Scripts']

package_data = \
{'': ['*'],
 'telecoin': ['venv/*',
              'venv/Lib/site-packages/PySocks-1.7.1.dist-info/*',
              'venv/Lib/site-packages/Pyrogram-1.2.9.dist-info/*',
              'venv/Lib/site-packages/aiohttp-3.7.4.post0.dist-info/*',
              'venv/Lib/site-packages/aiohttp/.hash/*',
              'venv/Lib/site-packages/async_lru-1.0.2.dist-info/*',
              'venv/Lib/site-packages/async_timeout-3.0.1.dist-info/*',
              'venv/Lib/site-packages/attrs-21.2.0.dist-info/*',
              'venv/Lib/site-packages/chardet-4.0.0.dist-info/*',
              'venv/Lib/site-packages/idna-3.2.dist-info/*',
              'venv/Lib/site-packages/multidict-5.1.0.dist-info/*',
              'venv/Lib/site-packages/multidict/_multilib/*',
              'venv/Lib/site-packages/pip-21.1.2.dist-info/*',
              'venv/Lib/site-packages/pyaes-1.6.1.dist-info/*',
              'venv/Lib/site-packages/setuptools-57.0.0.dist-info/*',
              'venv/Lib/site-packages/typing_extensions-3.10.0.2.dist-info/*',
              'venv/Lib/site-packages/wheel-0.36.2.dist-info/*',
              'venv/Lib/site-packages/yarl-1.6.3.dist-info/*']}

install_requires = \
['Pyrogram==1.2.9', 'aiohttp==3.7.4.post0']

setup_kwargs = {
    'name': 'telecoin',
    'version': '0.0.4',
    'description': 'Simple library to make payments via telegram bitcoin exchangers',
    'long_description': '**Slava Fisting Anal**',
    'author': 'Marple',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/marple-git/telecoin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
